@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime
 import copy
+import decimal
 import slumber
 import urlparse
 
@@ -54,7 +55,7 @@ class QuerySet(object):
         if len(self) < 1:
             raise StopIteration()
         index, length = 0, 0
-        klass = self._clone(self._responses)  #  klass = copy.deepcopy(self)
+        klass = self._clone(self._responses)  # klass = copy.deepcopy(self)
         while 1:
             try:
                 yield klass._objects[index]
@@ -220,13 +221,12 @@ class QuerySet(object):
     def _filter(self, *args, **kwargs):
         """
 
-        .. note:: No request args(Empty request params).
+        .. note:: No request args(== Empty request params).
 
-            - × e.p. id__in=[] -> http://no.com/?any=search
-            - ○ e.p. id__in=[] -> http://no.com/?any=search&id__in=
+            -  * e.g. id__in=[] -> http://no.com/?any=search
+            -  o e.g. id__in=[] -> http://no.com/?any=search&id__in=
 
-
-        .. note:: overwrite, id__in
+        .. note:: Overwrite id__in
 
         """
 
@@ -353,7 +353,7 @@ class ManyToManyManager(Manager):
 
     def filter(self, *args, **kwargs):
         if "id__in" in kwargs:
-            raise NotImplementedError("'id__in' does not allow ManyToManyManager.")
+            raise NotImplementedError("'id__in' does not allowed in ManyToManyManager.")
         return QuerySet(self.model, query=self._query).filter(*args, **kwargs)
 
     def add(self, *objs):
@@ -417,7 +417,7 @@ def parse_id(resource_uri):
 
     :param resource_uri:
     :rtype: str
-    :return: primary id
+    :return: Primary id
     """
     return resource_uri.split("/")[::-1][1]
 
@@ -426,8 +426,8 @@ class Response(object):
     """ Proxy Model Class """
     def __init__(self, model, response=None, url=None, **kwargs):
         """
-        :param model: The Model
-        :param response: response from Client Library
+        :param model: The Model.
+        :param response: Response from client library.
         """
         self.__response = response or dict()
         self._schema = model.schema()
@@ -566,6 +566,12 @@ def model_gen(**configs):
                                     check_type = value.isdigit()
                                 elif isinstance(value, int):
                                     check_type = True
+                            elif field_type == "float":
+                                if isinstance(value, float):
+                                    check_type = True
+                            elif field_type == "decimal":
+                                value = decimal.Decimal(value)
+                                check_type = isinstance(value, decimal.Decimal)
                             elif field_type == "datetime":
                                 if isinstance(value, (str, unicode)):
                                     try:
@@ -598,7 +604,11 @@ def model_gen(**configs):
                         if field_type == "string":
                             pass
                         elif field_type == "integer":
-                            pass  #  input safe
+                            pass   # input safe
+                        elif field_type == "float":
+                            pass   # input safe
+                        elif field_type == "decimal":
+                            pass   # input safe
                         elif field_type == "datetime":
                             value = value.isoformat()
                         elif field_type == "time":
@@ -661,7 +671,8 @@ def model_gen(**configs):
             if hasattr(self, "id"):
                 self._client(self.id).put(self._get_fields())  # return bool
             else:
-                self._setattrs(**self._client.post(self._get_fields()))
+                self._client.post(self._get_fields())
+                self._setattrs(**self._client._handle_redirect(self._client._))
 
         def delete(self):
             """ delete
@@ -707,7 +718,7 @@ class Client(object):
     def __init__(self, base_url, auth=None, strict_field=True, client=None):
         """
 
-        :param str base_url: e.p. http://api.base.biz/base/v1/
+        :param str base_url: e.g. http://api.base.biz/base/v1/
         :param auth:
         :param bool strict_field: strict field and convert value in field.
         :param object client:
@@ -734,7 +745,7 @@ class Client(object):
         request_url = self._url_gen(url)
         s = self._main_client._store
         requests = s["session"]
-        serializer = slumber.serialize.Serializer(default_format=s["format"])
+        serializer = slumber.serialize.Serializer(default=s["format"])
         return serializer.loads(requests.request(method, request_url).content)
 
     def schema(self, model_name=None):
@@ -769,4 +780,4 @@ class Client(object):
         return model_gen(
             main_client=self._main_client, model_name=model_name,
             endpoint=schema[model_name]["list_endpoint"], schema=schema[model_name]["schema"],
-            strict_field=strict_field, base_client=base_client or copy.deepcopy(self))
\ No newline at end of file
+            strict_field=strict_field, base_client=base_client or copy.copy(self))
